![cropped dragon gif](docs/cropped.gif)

# mercutio

[![Build Status](https://travis-ci.org/signebedi/mercutio.svg?branch=master)](https://travis-ci.org/signebedi/mercutio)
[![Inline docs](https://readthedocs.org/projects/pip/badge/?version=latest&style=flat)](https://mercutio.readthedocs.io/en/latest/)
[![PyPI](https://img.shields.io/pypi/v/mercutio?color=%230080)](https://pypi.org/project/mercutio/)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg?color=%230080)](LICENSE)
[![Requirements Status](https://requires.io/github/signebedi/mercutio/requirements.svg?branch=master&style=flat)](https://requires.io/github/signebedi/mercutio/requirements/?branch=master)

yet another character creation engine

Read the docs at [mercutio.readthedocs.io/en/latest/](https://mercutio.readthedocs.io/en/latest/).

---
Copyright (c) 2020 Signe Janoska-Bedi